@@ -368,16 +368,16 @@ def execute_task_chain(flat_deps_reverse: List[BuildDependency]):
         # saves a helper autocomplete includes txt file to make adding .vscode include paths easier
         _save_vscode_compile_commands(dep)
 
-        if dep.config.verbose:
+        if dep.config.verbose and not dep.config.test:
             if dep.is_root_or_config_target():
                 print_dependencies(dep)
             # else:
             #     print_dependencies(dep) # TODO: different output for non-root targets
 
 
-def find_dependency(root: BuildDependency, name) -> BuildDependency:
+def find_dependency(root: BuildDependency, name: str) -> BuildDependency:
     """ This is mainly used for finding root target or specific command line target """
-    if root.name == name:
+    if root.name.lower() == name.lower():
         return root
     for dep in root.get_children():
         found = find_dependency(dep, name)
